# Import APM package
from APMonitor.apm import *
import numpy as np

# Select server
server = 'http://byu.apmonitor.com'

# Optimize at mesh points
x = np.arange(20.0, 30.0, 2.0)
y = np.arange(30.0, 50.0, 4.0)
a, b = np.meshgrid(x, y)

# Initialize results array
obj = np.empty_like(a)

# Application name
app = 'nlp'

# Clear previous application
apm(server,app,'clear all')

# Load model file
apm_load(server,app,'nlp.apm')

# Calculate ob at all meshgrid points
for i in range(a.shape[0]):
    for j in range(b.shape[1]):

        # Designate parameters to change
        apm_info(server,app,'FV','a')
        apm_info(server,app,'FV','b')

        # Change parameter values
        apm_meas(server,app,'a',a[i,j])
        apm_meas(server,app,'b',b[i,j])

        # Solve on APM server
        solver_output = apm(server,app,'solve')

        # Retrieve results
        sol = apm_sol(server,app)

        print('--- Results of the Optimization Problem ---')
        print('ob  : ', sol['ob'])
        print('x1  : ', sol['x1'])
        print('x2  : ', sol['x2'])
        print('x3  : ', sol['x3'])
        print('x4  : ', sol['x4'])

        obj[i,j] = sol['ob']

# plot 3D figure of results
from mpl_toolkits.mplot3d import Axes3D
import matplotlib.pyplot as plt
from matplotlib import cm
import numpy as np

fig = plt.figure()
ax = fig.gca(projection='3d')
surf = ax.plot_surface(a, b, obj, \
                       rstride=1, cstride=1, cmap=cm.coolwarm, \
                       vmin = 10, vmax = 25, linewidth=0, antialiased=False)
ax.set_xlabel('a')
ax.set_ylabel('b')
ax.set_zlabel('obj')
plt.show()


